@@ -65,19 +65,21 @@ from igraph._igraph import (
     arpack_options as default_arpack_options,
     community_to_membership,
     convex_hull,
+    is_bigraphical,
     is_degree_sequence,
     is_graphical,
     is_graphical_degree_sequence,
     set_progress_handler,
     set_random_number_generator,
     set_status_handler,
+    umap_compute_weights,
     __igraph_version__,
 )
 from igraph.adjacency import (
     _get_adjacency,
     _get_adjacency_sparse,
     _get_adjlist,
-    _get_incidence,
+    _get_biadjacency,
     _get_inclist,
 )
 from igraph.automorphisms import (
@@ -102,7 +104,6 @@ from igraph.bipartite import (
 from igraph.community import (
     _community_fastgreedy,
     _community_infomap,
-    _community_leading_eigenvector_naive,
     _community_leading_eigenvector,
     _community_label_propagation,
     _community_multilevel,
@@ -217,7 +218,7 @@ from igraph.io.random import (
 )
 from igraph.io.bipartite import (
     _construct_bipartite_graph,
-    _construct_incidence_bipartite_graph,
+    _construct_bipartite_graph_from_adjacency,
     _construct_full_bipartite_graph,
     _construct_random_bipartite_graph,
 )
@@ -254,10 +255,11 @@ from igraph.structural import (
     _outdegree,
     _degree_distribution,
     _pagerank,
-    _shortest_paths
+    _shortest_paths,
 )
 from igraph.summary import GraphSummary, summary
 from igraph.utils import (
+    deprecated,
     numpy_to_contiguous_memoryview,
     rescale,
 )
@@ -266,14 +268,6 @@ from igraph.version import __version__, __version_info__
 import os
 import sys
 
-from warnings import warn
-
-
-def deprecated(message):
-    """Prints a warning message related to the deprecation of some igraph
-    feature."""
-    warn(message, DeprecationWarning, stacklevel=3)
-
 
 class Graph(GraphBase):
     """Generic graph.
@@ -360,7 +354,7 @@ class Graph(GraphBase):
 
         @keyword n: the number of vertices. Can be omitted, the default is
           zero. Note that if the edge list contains vertices with indexes
-          larger than or equal to M{m}, then the number of vertices will
+          larger than or equal to M{n}, then the number of vertices will
           be adjusted accordingly.
         @keyword edges: the edge list where every list item is a pair of
           integers. If any of the integers is larger than M{n-1}, the number
@@ -368,10 +362,13 @@ class Graph(GraphBase):
         @keyword directed: whether the graph should be directed
         @keyword graph_attrs: the attributes of the graph as a dictionary.
         @keyword vertex_attrs: the attributes of the vertices as a dictionary.
-          Every dictionary value must be an iterable with exactly M{n} items.
-        @keyword edge_attrs: the attributes of the edges as a dictionary. Every
-          dictionary value must be an iterable with exactly M{m} items where
-          M{m} is the number of edges.
+          The keys of the dictionary must be the names of the attributes; the
+          values must be iterables with exactly M{n} items where M{n} is the
+          number of vertices.
+        @keyword edge_attrs: the attributes of the edges as a dictionary. The
+          keys of the dictionary must be the names of the attributes; the values
+          must be iterables with exactly M{m} items where M{m} is the number of
+          edges.
         """
         # Pop the special __ptr keyword argument
         ptr = kwds.pop("__ptr", None)
@@ -516,7 +513,7 @@ class Graph(GraphBase):
 
     # Bipartite graphs
     Bipartite = classmethod(_construct_bipartite_graph)
-    Incidence = classmethod(_construct_incidence_bipartite_graph)
+    Biadjacency = classmethod(_construct_bipartite_graph_from_adjacency)
     Full_Bipartite = classmethod(_construct_full_bipartite_graph)
     Random_Bipartite = classmethod(_construct_random_bipartite_graph)
 
@@ -538,13 +535,13 @@ class Graph(GraphBase):
         See the documentation of L{GraphSummary} for more details about the
         output.
         """
-        params = dict(
-            verbosity=1,
-            width=78,
-            print_graph_attributes=False,
-            print_vertex_attributes=False,
-            print_edge_attributes=False,
-        )
+        params = {
+            "verbosity": 1,
+            "width": 78,
+            "print_graph_attributes": False,
+            "print_vertex_attributes": False,
+            "print_edge_attributes": False,
+        }
         return self.summary(**params)
 
     def summary(self, verbosity=0, width=None, *args, **kwds):
@@ -624,7 +621,7 @@ class Graph(GraphBase):
     get_adjacency = _get_adjacency
     get_adjacency_sparse = _get_adjacency_sparse
     get_adjlist = _get_adjlist
-    get_incidence = _get_incidence
+    get_biadjacency = _get_biadjacency
     get_inclist = _get_inclist
 
     #############################################
@@ -656,7 +653,6 @@ class Graph(GraphBase):
     # Community detection/clustering
     community_fastgreedy = _community_fastgreedy
     community_infomap = _community_infomap
-    community_leading_eigenvector_naive = _community_leading_eigenvector_naive
     community_leading_eigenvector = _community_leading_eigenvector
     community_label_propagation = _community_label_propagation
     community_multilevel = _community_multilevel
@@ -789,6 +785,9 @@ class Graph(GraphBase):
     def spanning_tree(self, weights=None, return_tree=True):
         """Calculates a minimum spanning tree for a graph.
 
+        B{Reference}: Prim, R.C. Shortest connection networks and some
+        generalizations. I{Bell System Technical Journal} 36:1389-1401, 1957.
+
         @param weights: a vector containing weights for every edge in
           the graph. C{None} means that the graph is unweighted.
         @param return_tree: whether to return the minimum spanning tree (when
@@ -799,10 +798,6 @@ class Graph(GraphBase):
         @return: the spanning tree as a L{Graph} object if C{return_tree}
           is C{True} or the IDs of the edges that constitute the spanning
           tree if C{return_tree} is C{False}.
-
-        @newfield ref: Reference
-        @ref: Prim, R.C.: I{Shortest connection networks and some
-          generalizations}. Bell System Technical Journal 36:1389-1401, 1957.
         """
         result = GraphBase._spanning_tree(self, weights)
         if return_tree:
@@ -820,23 +815,23 @@ class Graph(GraphBase):
         from I{a} to I{b} or from I{b} to I{a} but not the other way round)
         and null (there is no connection between I{a} and I{b}).
 
+        B{Reference}: Holland, P.W. and Leinhardt, S. A Method for Detecting
+        Structure in Sociometric Data. I{American Journal of Sociology}, 70,
+        492-513, 1970.
+
         @return: a L{DyadCensus} object.
-        @newfield ref: Reference
-        @ref: Holland, P.W. and Leinhardt, S.  (1970).  A Method for Detecting
-          Structure in Sociometric Data.  American Journal of Sociology, 70,
-          492-513.
         """
         return DyadCensus(GraphBase.dyad_census(self, *args, **kwds))
 
     def triad_census(self, *args, **kwds):
         """Calculates the triad census of the graph.
 
+        B{Reference}: Davis, J.A. and Leinhardt, S. The Structure of
+        Positive Interpersonal Relations in Small Groups. In:
+        J. Berger (Ed.), Sociological Theories in Progress, Volume 2,
+        218-251. Boston: Houghton Mifflin (1972).
+
         @return: a L{TriadCensus} object.
-        @newfield ref: Reference
-        @ref: Davis, J.A. and Leinhardt, S.  (1972).  The Structure of
-          Positive Interpersonal Relations in Small Groups.  In:
-          J. Berger (Ed.), Sociological Theories in Progress, Volume 2,
-          218-251. Boston: Houghton Mifflin.
         """
         return TriadCensus(GraphBase.triad_census(self, *args, **kwds))
 
@@ -859,6 +854,14 @@ class Graph(GraphBase):
         measure (see L{transitivity_undirected()}) as it simply takes the
         average local transitivity across the whole network.
 
+        B{References}
+
+          - Watts DJ and Strogatz S: Collective dynamics of small-world
+            networks. I{Nature} 393(6884):440-442, 1998.
+          - Barrat A, Barthelemy M, Pastor-Satorras R and Vespignani A:
+            The architecture of complex weighted networks. I{PNAS} 101, 3747
+            (2004). U{http://arxiv.org/abs/cond-mat/0311416}.
+
         @param mode: defines how to treat vertices with degree less than two.
           If C{TRANSITIVITY_ZERO} or C{"zero"}, these vertices will have zero
           transitivity. If C{TRANSITIVITY_NAN} or C{"nan"}, these vertices
@@ -867,12 +870,6 @@ class Graph(GraphBase):
           or even an edge attribute name.
 
         @see: L{transitivity_undirected()}, L{transitivity_local_undirected()}
-        @newfield ref: Reference
-        @ref: Watts DJ and Strogatz S: I{Collective dynamics of small-world
-          networks}. Nature 393(6884):440-442, 1998.
-        @ref: Barrat A, Barthelemy M, Pastor-Satorras R and Vespignani A:
-          I{The architecture of complex weighted networks}. PNAS 101, 3747 (2004).
-          U{http://arxiv.org/abs/cond-mat/0311416}.
         """
         if weights is None:
             return GraphBase.transitivity_avglocal_undirected(self, mode)
@@ -942,6 +939,23 @@ class Graph(GraphBase):
     __iter__ = None  # needed for PyPy
     __hash__ = None  # needed for PyPy
 
+    ###########################
+    # Deprecated functions
+
+    @classmethod
+    def Incidence(cls, *args, **kwds):
+        """Deprecated alias to L{Graph.Biadjacency()}."""
+        deprecated("Graph.Incidence() is deprecated; use Graph.Biadjacency() instead")
+        return cls.Biadjacency(*args, **kwds)
+
+    def get_incidence(self, *args, **kwds):
+        """Deprecated alias to L{Graph.get_biadjacency()}."""
+        deprecated(
+            "Graph.get_incidence() is deprecated; use Graph.get_biadjacency() "
+            "instead"
+        )
+        return self.get_biadjacency(*args, **kwds)
+
 
 ##############################################################
 # I/O format mapping
@@ -1035,7 +1049,7 @@ save = write
 
 ##############################################################
 # Configuration singleton instance
-config = init_configuration()
+config: Configuration = init_configuration()
 """The main configuration object of igraph. Use this object to modify igraph's
 behaviour, typically when used in interactive mode.
 """
@@ -1061,7 +1075,7 @@ del (
     _construct_graph_from_dataframe,
     _construct_random_geometric_graph,
     _construct_bipartite_graph,
-    _construct_incidence_bipartite_graph,
+    _construct_bipartite_graph_from_adjacency,
     _construct_full_bipartite_graph,
     _construct_random_bipartite_graph,
     _construct_graph_from_networkx,
@@ -1074,7 +1088,6 @@ del (
     _export_graph_to_tuple_list,
     _community_fastgreedy,
     _community_infomap,
-    _community_leading_eigenvector_naive,
     _community_leading_eigenvector,
     _community_label_propagation,
     _community_multilevel,
@@ -1118,123 +1131,126 @@ del (
 # Because _igraph starts with an underscore, pydoctor skips the whole docs
 # except for the objects mentioned down here.
 __all__ = (
-    'config',
-    'AdvancedGradientPalette',
-    'BoundingBox',
-    'CairoGraphDrawer',
-    'ClusterColoringPalette',
-    'Clustering',
-    'CohesiveBlocks',
-    'Configuration',
-    'Cover',
-    'Cut',
-    'DefaultGraphDrawer',
-    'Dendrogram',
-    'DyadCensus',
-    'Edge',
-    'EdgeSeq',
-    'FittedPowerLaw',
-    'Flow',
-    'GradientPalette',
-    'Graph',
-    'GraphBase',
-    'GraphSummary',
-    'Histogram',
-    'InternalError',
-    'Layout',
-    'Matching',
-    'MatplotlibGraphDrawer',
-    'Matrix',
-    'Palette',
-    'Plot',
-    'Point',
-    'PrecalculatedPalette',
-    'RainbowPalette',
-    'Rectangle',
-    'RunningMean',
-    'TriadCensus',
-    'UniqueIdGenerator',
-    'Vertex',
-    'VertexClustering',
-    'VertexCover',
-    'VertexDendrogram',
-    'VertexSeq',
-    'autocurve',
-    'color_name_to_rgb',
-    'color_name_to_rgba',
-    'community_to_membership',
-    'compare_communities',
-    'convex_hull',
-    'default_arpack_options',
-    'disjoint_union',
-    'get_include',
-    'hsla_to_rgba',
-    'hsl_to_rgb',
-    'hsva_to_rgba',
-    'hsv_to_rgb',
-    'is_degree_sequence',
-    'is_graphical',
-    'is_graphical_degree_sequence',
-    'intersection',
-    'known_colors',
-    'load',
-    'mean',
-    'median',
-    'palettes',
-    'percentile',
-    'plot',
-    'power_law_fit',
-    'quantile',
-    'read',
-    'rescale',
-    'rgba_to_hsla',
-    'rgb_to_hsl',
-    'rgba_to_hsva',
-    'rgb_to_hsv',
-    'save',
-    'set_progress_handler',
-    'set_random_number_generator',
-    'set_status_handler',
-    'split_join_distance',
-    'summary',
-    'union',
-    'write',
-
+    "config",
+    "AdvancedGradientPalette",
+    "BoundingBox",
+    "CairoGraphDrawer",
+    "ClusterColoringPalette",
+    "Clustering",
+    "CohesiveBlocks",
+    "Configuration",
+    "Cover",
+    "Cut",
+    "DefaultGraphDrawer",
+    "Dendrogram",
+    "DyadCensus",
+    "Edge",
+    "EdgeSeq",
+    "FittedPowerLaw",
+    "Flow",
+    "GradientPalette",
+    "Graph",
+    "GraphBase",
+    "GraphSummary",
+    "Histogram",
+    "InternalError",
+    "Layout",
+    "Matching",
+    "MatplotlibGraphDrawer",
+    "Matrix",
+    "Palette",
+    "Plot",
+    "Point",
+    "PrecalculatedPalette",
+    "RainbowPalette",
+    "Rectangle",
+    "RunningMean",
+    "TriadCensus",
+    "UniqueIdGenerator",
+    "Vertex",
+    "VertexClustering",
+    "VertexCover",
+    "VertexDendrogram",
+    "VertexSeq",
+    "autocurve",
+    "color_name_to_rgb",
+    "color_name_to_rgba",
+    "community_to_membership",
+    "compare_communities",
+    "convex_hull",
+    "default_arpack_options",
+    "disjoint_union",
+    "get_include",
+    "hsla_to_rgba",
+    "hsl_to_rgb",
+    "hsva_to_rgba",
+    "hsv_to_rgb",
+    "is_bigraphical",
+    "is_degree_sequence",
+    "is_graphical",
+    "is_graphical_degree_sequence",
+    "intersection",
+    "known_colors",
+    "load",
+    "mean",
+    "median",
+    "palettes",
+    "percentile",
+    "plot",
+    "power_law_fit",
+    "quantile",
+    "read",
+    "rescale",
+    "rgba_to_hsla",
+    "rgb_to_hsl",
+    "rgba_to_hsva",
+    "rgb_to_hsv",
+    "save",
+    "set_progress_handler",
+    "set_random_number_generator",
+    "set_status_handler",
+    "split_join_distance",
+    "summary",
+    "umap_compute_weights",
+    "union",
+    "write",
+    "__igraph_version__",
+    "__version__",
+    "__version_info__",
     # enums and stuff
-    'ADJ_DIRECTED',
-    'ADJ_LOWER',
-    'ADJ_MAX',
-    'ADJ_MIN',
-    'ADJ_PLUS',
-    'ADJ_UNDIRECTED',
-    'ADJ_UPPER',
-    'ALL',
-    'ARPACKOptions',
-    'BFSIter',
-    'BLISS_F',
-    'BLISS_FL',
-    'BLISS_FLM',
-    'BLISS_FM',
-    'BLISS_FS',
-    'BLISS_FSM',
-    'DFSIter',
-    'GET_ADJACENCY_BOTH',
-    'GET_ADJACENCY_LOWER',
-    'GET_ADJACENCY_UPPER',
-    'IN',
-    'OUT',
-    'REWIRING_SIMPLE',
-    'REWIRING_SIMPLE_LOOPS',
-    'STAR_IN',
-    'STAR_MUTUAL',
-    'STAR_OUT',
-    'STAR_UNDIRECTED',
-    'STRONG',
-    'TRANSITIVITY_NAN',
-    'TRANSITIVITY_ZERO',
-    'TREE_IN',
-    'TREE_OUT',
-    'TREE_UNDIRECTED',
-    'WEAK',
-
+    "ADJ_DIRECTED",
+    "ADJ_LOWER",
+    "ADJ_MAX",
+    "ADJ_MIN",
+    "ADJ_PLUS",
+    "ADJ_UNDIRECTED",
+    "ADJ_UPPER",
+    "ALL",
+    "ARPACKOptions",
+    "BFSIter",
+    "BLISS_F",
+    "BLISS_FL",
+    "BLISS_FLM",
+    "BLISS_FM",
+    "BLISS_FS",
+    "BLISS_FSM",
+    "DFSIter",
+    "GET_ADJACENCY_BOTH",
+    "GET_ADJACENCY_LOWER",
+    "GET_ADJACENCY_UPPER",
+    "IN",
+    "OUT",
+    "REWIRING_SIMPLE",
+    "REWIRING_SIMPLE_LOOPS",
+    "STAR_IN",
+    "STAR_MUTUAL",
+    "STAR_OUT",
+    "STAR_UNDIRECTED",
+    "STRONG",
+    "TRANSITIVITY_NAN",
+    "TRANSITIVITY_ZERO",
+    "TREE_IN",
+    "TREE_OUT",
+    "TREE_UNDIRECTED",
+    "WEAK",
 )
